import { Logger } from "@nestjs/common";
import { NestFactory } from "@nestjs/core";
import { DocumentBuilder, SwaggerModule } from "@nestjs/swagger";

import helmet from "helmet";
import { AppModule } from "./app/app.module";

async function bootstrap() {
	const config = new DocumentBuilder()
		.setTitle("Fab Explorer")
		.setDescription("Définition de l'api du FabLab Explorer")
		.setVersion("1.0")
		.build();

	const app = await NestFactory.create(AppModule);
	const globalPrefix = "api";
	app.setGlobalPrefix(globalPrefix);
	app.use(helmet());
	const port = process.env.PORT || 3333;

	const document = SwaggerModule.createDocument(app, config);
	SwaggerModule.setup("api", app, document);

	await app.listen(port);
	Logger.log(
		`🚀 Application is running on: http://localhost:${port}/${globalPrefix}`,
	);
}

bootstrap();
